﻿Set-StrictMode -Version 2

Function Test-CVE201715361TPM  {
    <#
    .SYNOPSIS
    Tests if a Windows system has an enabled Trusted Platform Module (TPM) that is vulnerable to CVE-2017-15361.

    .DESCRIPTION
    Tests if a Windows system has an enabled Trusted Platform Module (TPM) that is vulnerable to CVE-2017-15361. Requiures PowerShell 2.0 or later. Must be run with administrator privileges.

    .EXAMPLE
    Test-CVE201715361TPM 
    #>
    [CmdletBinding()]
    Param()

    $vulnerable = $false

    $tpm = $null

    try {
        $tpm = Get-WmiObject -Class 'Win32_TPM' -Namespace 'root/cimv2/Security/MicrosoftTPM' -ErrorAction SilentlyContinue
    } catch {}

    if ($tpm -ne $null) {
        if($tpm.ManufacturerId -eq 0x49465800) {
            if ($tpm.ManufacturerVersion.Length -ge 3) {
                $version = [System.Version]$tpm.ManufacturerVersion

                switch ($version.Major) {
                    4 {$vulnerable = ($version.Minor -le 33 -or @(40..42) -contains $version.Minor);break}
                    5 {$vulnerable = ($version.Minor -le 61);break}
                    6 {$vulnerable = ($version.Minor -le 42);break}
                    7 {$vulnerable = ($version.Minor -le 61);break}
                    133 {$vulnerable = ($version.Minor -le 32);break}
                    149 {$vulnerable = ($version.Minor -le 32);break}
                    default {$vulnerable = $false;break}  
                }
            }
        } 
    }
    $vulnerable
}

Test-CVE201715361TPM